@@ -2,7 +2,11 @@ use strict;
 use warnings;
 
 package HTTP::CookieMonster;
-$HTTP::CookieMonster::VERSION = '0.07';
+$HTTP::CookieMonster::VERSION = '0.08';
+$HTTP::CookieMonster::VERSION = '0.08';
+
+use 5.006;
+
 use Moo;
 use Carp qw( croak );
 use HTTP::Cookies;
@@ -10,14 +14,14 @@ use HTTP::CookieMonster::Cookie;
 use Safe::Isa;
 use Scalar::Util qw( reftype );
 use Sub::Exporter -setup => { exports => ['cookies'] };
+use URI::Escape qw( uri_escape uri_unescape );
 
 my @_cookies = ();
-
 has 'cookie_jar' => (
     required => 1,
     is       => 'ro',
     isa      => sub {
-        die "HTTP::Cookies object expected"
+        croak 'HTTP::Cookies object expected'
             if !$_[0]->$_isa( 'HTTP::Cookies' );
         }
 
@@ -37,46 +41,41 @@ sub BUILDARGS {
 # should be minimal and this keeps things simple.
 
 sub all_cookies {
-
     my $self = shift;
     @_cookies = ();
     $self->cookie_jar->scan( \&_check_cookies );
 
     wantarray ? return @_cookies : return \@_cookies;
-
 }
 
-
 # my $cookie = cookies( $jar ); -- first cookie (makes no sense)
 # my $session = cookies( $jar, 'session' );
 # my @cookies = cookies( $jar );
 # my @sessions = cookies( $jar, 'session' );
 
 sub cookies {
-
     my ( $cookie_jar, $name ) = @_;
-    die "This function is not part of the OO interface"
+    croak 'This function is not part of the OO interface'
         if $cookie_jar->$_isa( 'HTTP::CookieMonster' );
 
     my $monster = HTTP::CookieMonster->new( $cookie_jar );
 
     if ( !$name ) {
         if ( !wantarray ) {
-            croak "Please specify a cookie name when asking for a single cookie";
+            croak
+                'Please specify a cookie name when asking for a single cookie';
         }
         return @{ $monster->all_cookies };
     }
 
     return $monster->get_cookie( $name );
-
 }
 
 sub get_cookie {
-
     my $self = shift;
     my $name = shift;
 
-    my @cookies = ( );
+    my @cookies = ();
     foreach my $cookie ( $self->all_cookies ) {
         if ( $cookie->key eq $name ) {
             return $cookie if !wantarray;
@@ -86,11 +85,9 @@ sub get_cookie {
 
     return shift @cookies if !wantarray;
     return @cookies;
-
 }
 
 sub set_cookie {
-
     my $self   = shift;
     my $cookie = shift;
 
@@ -99,16 +96,16 @@ sub set_cookie {
     }
 
     return $self->cookie_jar->set_cookie(
-        $cookie->version,   $cookie->key,    $cookie->val,
-        $cookie->path,      $cookie->domain, $cookie->port,
-        $cookie->path_spec, $cookie->secure, $cookie->expires,
-        $cookie->discard,   $cookie->hash
+        $cookie->version,           $cookie->key,
+        uri_escape( $cookie->val ), $cookie->path,
+        $cookie->domain,            $cookie->port,
+        $cookie->path_spec,         $cookie->secure,
+        $cookie->expires,           $cookie->discard,
+        $cookie->hash
     ) ? 1 : 0;
-
 }
 
 sub delete_cookie {
-
     my $self   = shift;
     my $cookie = shift;
 
@@ -119,19 +116,16 @@ sub delete_cookie {
     $cookie->expires( -1 );
 
     return $self->set_cookie( $cookie );
-
 }
 
-
 sub _check_cookies {
-
     my @args = @_;
 
     push @_cookies,
         HTTP::CookieMonster::Cookie->new(
         version   => $args[0],
         key       => $args[1],
-        val       => $args[2],
+        val       => uri_unescape( $args[2] ),
         path      => $args[3],
         domain    => $args[4],
         port      => $args[5],
@@ -162,7 +156,7 @@ HTTP::CookieMonster - Easy read/write access to your jar of HTTP::Cookies
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
