@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package HTTP::CookieMonster::Cookie;
-$HTTP::CookieMonster::Cookie::VERSION = '0.07';
+$HTTP::CookieMonster::Cookie::VERSION = '0.08';
 use Moo;
 
 # in order of args required in $cookie_jar->scan callback
@@ -35,7 +35,7 @@ HTTP::CookieMonster::Cookie - Cookie representation used by HTTP::CookieMonster
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -96,6 +96,11 @@ The value of the cookie.
 
     $cookie->value( "random_stuff" );
 
+If you are creating a new cookie, you should escape the value first.
+
+    use URI::Escape qw( uri_escape );
+    $cookie->value( uri_escape( 'random_stuff' ) );
+
 =head2 path
 
     $cookie->path( "/" );
@@ -124,6 +129,12 @@ The value of the cookie.
 
     $cookie->hash( { HttpOnly => undef } );
 
+=head1 SEE ALSO
+
+This is mainly useful for creating cookies to be used by L<LWP::UserAgent> and
+L<WWW::Mechanize classes>.  If you need to create cookies to set via headers,
+have a look at L<Cookie::Baker>.
+
 =head1 AUTHOR
 
 Olaf Alders <olaf@wundercounter.com>
